@@ -15,8 +15,8 @@
 #
 
 import copy
+from unittest import mock
 
-import mock
 from osc_lib.tests import utils as osctestutils
 
 from ironicclient.osc.v1 import baremetal_portgroup
