@@ -18,8 +18,6 @@ import logging
 from ironicclient.common import filecache
 from ironicclient.common import http
 from ironicclient.common.http import DEFAULT_VER
-from ironicclient.common.i18n import _
-from ironicclient import exc
 from ironicclient.v1 import allocation
 from ironicclient.v1 import chassis
 from ironicclient.v1 import conductor
@@ -38,26 +36,23 @@ LOG = logging.getLogger(__name__)
 class Client(object):
     """Client for the Ironic v1 API.
 
-    :param string endpoint: A user-supplied endpoint URL for the ironic
-                            service. DEPRECATED, use endpoint_override instead.
     :param string endpoint_override: A user-supplied endpoint URL for the
                                      ironic service.
-    :param function token: Provides token for authentication.
-    :param integer timeout: Allows customization of the timeout for client
-                            http requests. (optional)
+    :param session: A keystoneauth Session object (must be provided as
+        a keyword argument).
     """
 
-    def __init__(self, endpoint=None, endpoint_override=None, *args, **kwargs):
+    def __init__(self, endpoint_override=None, *args, **kwargs):
         """Initialize a new client for the Ironic v1 API."""
+        if not args and not kwargs.get('session'):
+            raise TypeError("A session is required for creating a client, "
+                            "use ironicclient.client.get_client to create "
+                            "it automatically")
+
         allow_downgrade = kwargs.pop('allow_api_version_downgrade', False)
-        if endpoint_override is None and endpoint is not None:
-            LOG.warning('Passing "endpoint" parameter to Client constructor '
-                        'is deprecated, and it will be removed in Stein '
-                        'release. Please use "endpoint_override" instead.')
-            endpoint_override = endpoint
         if kwargs.get('os_ironic_api_version'):
             # TODO(TheJulia): We should sanity check os_ironic_api_version
-            # against our maximum suported version, so the client fails
+            # against our maximum supported version, so the client fails
             # immediately upon an unsupported version being provided.
             # This logic should also likely live in common/http.py
             if allow_downgrade:
@@ -73,23 +68,26 @@ class Client(object):
             else:
                 kwargs['api_version_select_state'] = "user"
         else:
-            if not endpoint_override:
-                raise exc.EndpointException(
-                    _("Must provide 'endpoint_override' if "
-                      "'os_ironic_api_version' isn't specified"))
-
-            # If the user didn't specify a version, use a cached version if
-            # one has been stored
-            host, netport = http.get_server(endpoint_override)
-            saved_version = filecache.retrieve_data(host=host, port=netport)
-            if saved_version:
-                kwargs['api_version_select_state'] = "cached"
-                kwargs['os_ironic_api_version'] = saved_version
+            if endpoint_override:
+                # If the user didn't specify a version, use a cached version if
+                # one has been stored
+                host, netport = http.get_server(endpoint_override)
+                saved_version = filecache.retrieve_data(host=host,
+                                                        port=netport)
+                if saved_version:
+                    kwargs['api_version_select_state'] = "cached"
+                    kwargs['os_ironic_api_version'] = saved_version
+                else:
+                    kwargs['api_version_select_state'] = "default"
+                    kwargs['os_ironic_api_version'] = DEFAULT_VER
             else:
+                LOG.debug('Cannot use cached API version since endpoint '
+                          'override is not provided. Will negotiate again.')
                 kwargs['api_version_select_state'] = "default"
                 kwargs['os_ironic_api_version'] = DEFAULT_VER
 
-        kwargs['endpoint_override'] = endpoint_override
+        if endpoint_override:
+            kwargs['endpoint_override'] = endpoint_override
         self.http_client = http._construct_http_client(*args, **kwargs)
 
         self.chassis = chassis.ChassisManager(self.http_client)
@@ -119,7 +117,7 @@ class Client(object):
 
     @property
     def is_api_version_negotiated(self):
-        """Returns True if microversion negotiation has occured."""
+        """Returns True if microversion negotiation has occurred."""
         return self.http_client.api_version_select_state == 'negotiated'
 
     def negotiate_api_version(self):
