@@ -14,7 +14,6 @@ import functools
 import json
 
 import jsonschema
-import six
 import yaml
 
 from ironicclient import exc
@@ -62,14 +61,14 @@ def create_resources(client, filenames):
     if errors:
         raise exc.ClientException('While validating the resources file(s), the'
                                   ' following error(s) were encountered:\n%s' %
-                                  '\n'.join(six.text_type(e) for e in errors))
+                                  '\n'.join(str(e) for e in errors))
     for r in resources:
         errors.extend(create_chassis(client, r.get('chassis', [])))
         errors.extend(create_nodes(client, r.get('nodes', [])))
     if errors:
         raise exc.ClientException('During resources creation, the following '
                                   'error(s) were encountered:\n%s' %
-                                  '\n'.join(six.text_type(e) for e in errors))
+                                  '\n'.join(str(e) for e in errors))
 
 
 def load_from_file(filename):
