@@ -34,7 +34,8 @@ class PortManager(base.CreateManager):
 
     def list(self, address=None, limit=None, marker=None, sort_key=None,
              sort_dir=None, detail=False, fields=None, node=None,
-             portgroup=None):
+             portgroup=None, os_ironic_api_version=None,
+             global_request_id=None):
         """Retrieve a list of ports.
 
         :param address: Optional, MAC address of a port, to get
@@ -69,6 +70,12 @@ class PortManager(base.CreateManager):
         :param portgroup: Optional, name or UUID of a portgroup. Used to get
                           ports of this portgroup.
 
+        :param os_ironic_api_version: String version (e.g. "1.35") to use for
+            the request.  If not specified, the client's default is used.
+
+        :param global_request_id: String containing global request ID header
+            value (in form "req-<UUID>") to use for the request.
+
         :returns: A list of ports.
 
         """
@@ -93,24 +100,31 @@ class PortManager(base.CreateManager):
             path += 'detail'
         if filters:
             path += '?' + '&'.join(filters)
-
+        header_values = {"os_ironic_api_version": os_ironic_api_version,
+                         "global_request_id": global_request_id}
         if limit is None:
-            return self._list(self._path(path), "ports")
+            return self._list(self._path(path), "ports", **header_values)
         else:
             return self._list_pagination(self._path(path), "ports",
-                                         limit=limit)
+                                         limit=limit, **header_values)
 
-    def get(self, port_id, fields=None):
-        return self._get(resource_id=port_id, fields=fields)
+    def get(self, port_id, fields=None, os_ironic_api_version=None,
+            global_request_id=None):
+        return self._get(resource_id=port_id, fields=fields,
+                         os_ironic_api_version=os_ironic_api_version,
+                         global_request_id=global_request_id)
 
-    def get_by_address(self, address, fields=None):
+    def get_by_address(self, address, fields=None, os_ironic_api_version=None,
+                       global_request_id=None):
         path = '?address=%s' % address
         if fields is not None:
             path += '&fields=' + ','.join(fields)
         else:
             path = 'detail' + path
 
-        ports = self._list(self._path(path), 'ports')
+        ports = self._list(self._path(path), 'ports',
+                           os_ironic_api_version=os_ironic_api_version,
+                           global_request_id=global_request_id)
         # get all the details of the port assuming that filtering by
         # address returns a collection of one port if successful.
         if len(ports) == 1:
@@ -118,8 +132,14 @@ class PortManager(base.CreateManager):
         else:
             raise exc.NotFound()
 
-    def delete(self, port_id):
-        return self._delete(resource_id=port_id)
+    def delete(self, port_id, os_ironic_api_version=None,
+               global_request_id=None):
+        return self._delete(resource_id=port_id,
+                            os_ironic_api_version=os_ironic_api_version,
+                            global_request_id=global_request_id)
 
-    def update(self, port_id, patch):
-        return self._update(resource_id=port_id, patch=patch)
+    def update(self, port_id, patch, os_ironic_api_version=None,
+               global_request_id=None):
+        return self._update(resource_id=port_id, patch=patch,
+                            os_ironic_api_version=os_ironic_api_version,
+                            global_request_id=global_request_id)
