@@ -34,12 +34,13 @@ class Resource(object):
         'address': 'Address',
         'alive': 'Alive',
         'allocation_uuid': 'Allocation UUID',
+        'allowable_values': 'Allowable Values',
         'async': 'Async',
+        'attribute_type': 'Attribute Type',
         'automated_clean': 'Automated Clean',
         'attach': 'Response is attachment',
-        'bios_name': 'BIOS setting name',
-        'bios_value': 'BIOS setting value',
         'boot_index': 'Boot Index',
+        'boot_mode': 'Boot Mode',
         'candidate_nodes': 'Candidate Nodes',
         'chassis_uuid': 'Chassis UUID',
         'clean_step': 'Clean Step',
@@ -51,6 +52,7 @@ class Resource(object):
         'default_boot_interface': 'Default Boot Interface',
         'default_console_interface': 'Default Console Interface',
         'default_deploy_interface': 'Default Deploy Interface',
+        'default_firmware_interface': 'Default Firmware Interface',
         'default_inspect_interface': 'Default Inspect Interface',
         'default_management_interface': 'Default Management Interface',
         'default_network_interface': 'Default Network Interface',
@@ -69,6 +71,7 @@ class Resource(object):
         'enabled_boot_interfaces': 'Enabled Boot Interfaces',
         'enabled_console_interfaces': 'Enabled Console Interfaces',
         'enabled_deploy_interfaces': 'Enabled Deploy Interfaces',
+        'enabled_firmware_interfaces': 'Enabled Firmware Interfaces',
         'enabled_inspect_interfaces': 'Enabled Inspect Interfaces',
         'enabled_management_interfaces': 'Enabled Management Interfaces',
         'enabled_network_interfaces': 'Enabled Network Interfaces',
@@ -78,6 +81,8 @@ class Resource(object):
         'enabled_storage_interfaces': 'Enabled Storage Interfaces',
         'enabled_vendor_interfaces': 'Enabled Vendor Interfaces',
         'extra': 'Extra',
+        'event': 'Description of the event',
+        'event_type': 'Event Origin Type',
         'hostname': 'Hostname',
         'hosts': 'Active host(s)',
         'http_methods': 'Supported HTTP methods',
@@ -88,11 +93,15 @@ class Resource(object):
         'internal_info': 'Internal Info',
         'last_error': 'Last Error',
         'lessee': 'Lessee',
+        'lower_bound': 'Lower Bound',
         'maintenance': 'Maintenance',
         'maintenance_reason': 'Maintenance Reason',
+        'max_length': 'Maximum Length',
         'fault': 'Fault',
+        'min_length': 'Minimum Length',
         'mode': 'Mode',
         'name': 'Name',
+        'network_data': 'Network Configuration',
         'node_uuid': 'Node UUID',
         'owner': 'Owner',
         'power_state': 'Power State',
@@ -102,10 +111,13 @@ class Resource(object):
         'provision_state': 'Provisioning State',
         'provision_updated_at': 'Provision Updated At',
         'raid_config': 'Current RAID configuration',
+        'read_only': 'Read Only',
+        'reset_required': 'Reset Required',
         'reservation': 'Reservation',
         'resource_class': 'Resource Class',
         'retired': 'Retired',
         'retired_reason': 'Retired Reason',
+        'secure_boot': 'Secure Boot',
         'state': 'State',
         'steps': 'Steps',
         'target_power_state': 'Target Power State',
@@ -115,6 +127,7 @@ class Resource(object):
         'type': 'Type',
         'updated_at': 'Updated At',
         'uuid': 'UUID',
+        'value': 'Value',
         'volume_id': 'Volume ID',
         'volume_type': 'Driver Volume Type',
         'local_link_connection': 'Local Link Connection',
@@ -131,12 +144,19 @@ class Resource(object):
         'raid_interface': 'RAID Interface',
         'rescue_interface': 'Rescue Interface',
         'storage_interface': 'Storage Interface',
+        'severity': 'Severity',
+        'unique': 'Unique',
+        'upper_bound': 'Upper Bound',
+        'user': 'User',
         'vendor_interface': 'Vendor Interface',
         'standalone_ports_supported': 'Standalone Ports Supported',
         'physical_network': 'Physical Network',
         'id': 'ID',
         'connector_id': 'Connector ID',
         'is_smartnic': 'Is Smart NIC port',
+        'parent_node': 'Parent Node',
+        'children': 'Child Nodes',
+        'firmware_interface': 'Firmware Interface',
     }
 
     def __init__(self, field_ids, sort_excluded=None, override_labels=None):
@@ -222,6 +242,7 @@ NODE_DETAILED_RESOURCE = Resource(
      'automated_clean',
      'bios_interface',
      'boot_interface',
+     'boot_mode',
      'chassis_uuid',
      'clean_step',
      'conductor',
@@ -238,6 +259,7 @@ NODE_DETAILED_RESOURCE = Resource(
      'driver_internal_info',
      'extra',
      'fault',
+     'firmware_interface',
      'inspect_interface',
      'inspection_finished_at',
      'inspection_started_at',
@@ -249,8 +271,10 @@ NODE_DETAILED_RESOURCE = Resource(
      'maintenance_reason',
      'management_interface',
      'name',
+     'network_data',
      'network_interface',
      'owner',
+     'parent_node',
      'power_interface',
      'power_state',
      'properties',
@@ -264,6 +288,7 @@ NODE_DETAILED_RESOURCE = Resource(
      'resource_class',
      'retired',
      'retired_reason',
+     'secure_boot',
      'storage_interface',
      'target_power_state',
      'target_provision_state',
@@ -374,8 +399,29 @@ TRAIT_RESOURCE = Resource(
     ['traits'],
 )
 
+CHILDREN_RESOURCE = Resource(
+    ['children'],
+)
+
 BIOS_RESOURCE = Resource(
-    ['bios_name', 'bios_value'],
+    ['name', 'value'],
+    override_labels={'name': 'BIOS setting name',
+                     'value': 'BIOS setting value'}
+)
+
+BIOS_DETAILED_RESOURCE = Resource(
+    ['name',
+     'value',
+     'attribute_type',
+     'allowable_values',
+     'lower_bound',
+     'min_length',
+     'max_length',
+     'read_only',
+     'reset_required',
+     'unique',
+     'upper_bound'
+     ],
 )
 
 # Drivers
@@ -387,6 +433,7 @@ DRIVER_DETAILED_RESOURCE = Resource(
      'default_boot_interface',
      'default_console_interface',
      'default_deploy_interface',
+     'default_firmware_interface',
      'default_inspect_interface',
      'default_management_interface',
      'default_network_interface',
@@ -399,6 +446,7 @@ DRIVER_DETAILED_RESOURCE = Resource(
      'enabled_boot_interfaces',
      'enabled_console_interfaces',
      'enabled_deploy_interfaces',
+     'enabled_firmware_interfaces',
      'enabled_inspect_interfaces',
      'enabled_management_interfaces',
      'enabled_network_interfaces',
@@ -417,6 +465,22 @@ DRIVER_RESOURCE = Resource(
     override_labels={'name': 'Supported driver(s)'}
 )
 
+# Firmware
+FIRMWARE_RESOURCE = Resource(
+    ['component',
+     'initial_version',
+     'current_version',
+     'last_version_flashed',
+     'created_at',
+     'updated_at',
+     ],
+    override_labels={'component': 'Component',
+                     'initial_version': 'Initial Version',
+                     'current_version': 'Current Version',
+                     'last_version_flashed': 'Last Version Flashed'}
+)
+
+
 # Volume connectors
 VOLUME_CONNECTOR_DETAILED_RESOURCE = Resource(
     ['uuid',
@@ -539,3 +603,21 @@ DEPLOY_TEMPLATE_RESOURCE = Resource(
      'name',
      ],
 )
+
+
+NODE_HISTORY_RESOURCE = Resource(
+    ['uuid',
+     'created_at',
+     'severity',
+     'event']
+)
+
+NODE_HISTORY_DETAILED_RESOURCE = Resource(
+    ['uuid',
+     'created_at',
+     'severity',
+     'event_type',
+     'event',
+     'conductor',
+     'user']
+)
